use strict;
use warnings;
use Rstats;

my $inf = Inf;

print $inf;

1;
